from gpaw import GPAW
from ase.spacegroup import crystal
from ase.io import write

a = 4.6
c = 2.95

# Rutile TiO2:
atoms = crystal(['Ti', 'O'], basis=[(0, 0, 0), (0.3, 0.3, 0.0)],
                spacegroup=136, cellpar=[a, a, c, 90, 90, 90])
write('rutile.traj', atoms)

if 0:
    lat = atoms.cell.get_bravais_lattice()
    print(lat.description())
    assert lat.name == 'TET'

    calc = GPAW(mode='pw', kpts={'density': 1.0}, txt='gpaw.txt')
    atoms.calc = calc
    atoms.get_potential_energy()

    path = atoms.cell.bandpath('GXMGZRAZ,XR,MA', density=25)
    path.write('path.json')

    calc.set(fixdensity=True, kpts=path, symmetry='off')
    atoms.get_potential_energy()

    bs = calc.band_structure()
    #bs = path.free_electron_band_structure()
    bs.write('bs.json')
from ase.io import read
from gpaw import GPAW, PW
from ase.optimize import BFGS
from ase.constraints import ExpCellFilter
from ase.utils import workdir

atoms = read('rutile.traj')

with workdir('opt', mkdir=True):
    calc = GPAW(mode=PW(500), kpts={'density': 1.2},
                txt='gpaw.txt')
    atoms.calc = calc

    opt = BFGS(ExpCellFilter(atoms), trajectory='opt.traj',
               logfile='opt.log')
    opt.run(fmax=0.01)
